Index: doc/DRIVERS
===================================================================
RCS file: /usr/local/cvsroot/ao/doc/DRIVERS,v
retrieving revision 1.2
diff -u -r1.2 DRIVERS
--- doc/DRIVERS	2001/02/02 10:02:06	1.2
+++ doc/DRIVERS	2001/03/15 01:36:36
@@ -59,6 +59,18 @@
         "file" - Sets the output file.  By default, this is
                  "output.wav".
 
+raw
+---
+Raw sample output.  Writes the sound data to disk in uncompressed,
+headerless form using the byte order specified.  
+    Option keys:
+        "file" - Sets the output file.  Use "-" if you want to write
+                 to stdout.  By default this is "output.raw".
+
+        "byteorder" - Sets the byte order used in the output.  Use
+                      "native" for native machine byte order, "big"
+                      for big-endian order, and "little" for
+                      little-endian order.  By default this is "native".
 
 ADDING NEW DRIVERS
 
Index: include/ao/ao.h
===================================================================
RCS file: /usr/local/cvsroot/ao/include/ao/ao.h,v
retrieving revision 1.11
diff -u -r1.11 ao.h
--- include/ao/ao.h	2001/02/24 01:31:46	1.11
+++ include/ao/ao.h	2001/03/15 01:36:36
@@ -75,6 +75,7 @@
 
 #define AO_NULL     0
 #define AO_WAV      1
+#define AO_RAW      2
 
 /* --- Functions --- */
 
Index: src/Makefile.am
===================================================================
RCS file: /usr/local/cvsroot/ao/src/Makefile.am,v
retrieving revision 1.4
diff -u -r1.4 Makefile.am
--- src/Makefile.am	2000/10/30 00:46:41	1.4
+++ src/Makefile.am	2001/03/15 01:36:36
@@ -7,7 +7,7 @@
 
 lib_LTLIBRARIES = libao.la
 
-libao_la_SOURCES = audio_out.c ao_wav.c ao_null.c
+libao_la_SOURCES = audio_out.c ao_raw.c ao_wav.c ao_null.c
 libao_la_LDFLAGS = -version-info @LIB_CURRENT@:@LIB_REVISION@:@LIB_AGE@
 
 
Index: src/audio_out.c
===================================================================
RCS file: /usr/local/cvsroot/ao/src/audio_out.c,v
retrieving revision 1.13
diff -u -r1.13 audio_out.c
--- src/audio_out.c	2001/02/28 07:50:11	1.13
+++ src/audio_out.c	2001/03/15 01:36:36
@@ -55,6 +55,7 @@
 
 extern ao_functions_t ao_null;
 extern ao_functions_t ao_wav;
+extern ao_functions_t ao_raw;
 
 driver_tree_t *driver_head = NULL;
 
@@ -97,6 +98,7 @@
 {
 	driver_tree_t *dnull;
 	driver_tree_t *dwav;
+	driver_tree_t *draw;
 	driver_tree_t *plugin;
 	driver_tree_t *driver;
 	DIR *plugindir;
@@ -107,19 +109,23 @@
 	char fullpath[FILENAME_MAX];
 
 	if (driver_head == NULL) {
-		/* insert the null and wav drivers into the tree */
+		/* insert the null, wav, and raw drivers into the tree */
 		dnull = (driver_tree_t *)malloc(sizeof(driver_tree_t));
 		dnull->functions = &ao_null;
 		dnull->handle = NULL;
 		dwav = (driver_tree_t *)malloc(sizeof(driver_tree_t));
 		dwav->functions = &ao_wav;
 		dwav->handle = NULL;
+		draw = (driver_tree_t *)malloc(sizeof(driver_tree_t));
+		draw->functions = &ao_raw;
+		draw->handle = NULL;
 		
 		dnull->next = dwav;
-		dwav->next = NULL;
+		dwav->next = draw;
+		draw->next = NULL;
 
 		driver_head = dnull;		
-		driver = dwav;
+		driver = draw;
 
 		/* now insert any plugins we find */
 		plugindir = opendir(AO_PLUGIN_PATH);
@@ -151,7 +157,7 @@
 	if (!driver_head) return;
 
 	/* unload and free all the plugins */
-	driver = driver->next->next;
+	driver = driver->next->next->next; /* Skip null, wav, and raw driver */
 	while (driver) {
 		if (driver->functions) free(driver->functions);
 		if (driver->handle) dlclose(driver->handle);